@@ -2,15 +2,15 @@ package Webservice::InterMine::ResultIterator::Role::HTMLTableRow;
 
 use Moose::Role;
 
-requires qw(arrayref);
+requires qw(next);
 
 sub html_row {
     my $self = shift;
-    my $row  = $self->arrayref;
-    return unless (defined $row);
+    my $row  = $self->next;
+    return unless ( defined $row );
     my $output = "<tr>";
     for (@$row) {
-	$output .= "<td>$_</td>";
+        $output .= (defined $_) ? "<td>$_</td>" : "<td>[NONE]</td>";
     }
     $output .= "</tr>";
     return $output;
